import {Component, OnInit, ViewEncapsulation} from '@angular/core';
import {ActivatedRoute, Router} from "@angular/router";
import {Settings} from "common/core/config/settings.service";
import {TemplateColors} from "./template-colors";
import {Modal} from "common/core/ui/dialogs/modal.service";
import {BuilderProject, BuilderTemplate} from '../../shared/builder-types';
import {PaginationResponse} from '../../../common/core/types/pagination-response';
import {CrupdateProjectModalComponent} from '../../shared/crupdate-project-modal/crupdate-project-modal.component';

@Component({
    selector: 'new-project-page',
    templateUrl: './new-project-page.component.html',
    styleUrls: ['./new-project-page.component.scss'],
    encapsulation: ViewEncapsulation.None
})
export class NewProjectPageComponent implements OnInit {
    public colors = TemplateColors;
    public allCategories: string[] = [];
    public templatePagination: PaginationResponse<BuilderTemplate>;
    public filteredTemplates: BuilderTemplate[] = [];
    public selectedCategory: string | null;
    public selectedColor: string | null;

    constructor(
        private route: ActivatedRoute,
        private settings: Settings,
        private modal: Modal,
        private router: Router,
    ) {}

    ngOnInit() {
        this.allCategories = this.settings.getJson('builder.template_categories', []);

        this.route.data.subscribe(resolve => {
            this.templatePagination = resolve.templates;
            this.filteredTemplates = resolve.templates.data;
        });
    }

    public openNewProjectModal(templateName?: string) {
        this.modal.open(CrupdateProjectModalComponent, {templateName})
            .afterClosed().subscribe((project: BuilderProject) => {
                if ( ! project) return;
                this.router.navigate(['/builder', project.model.id]);
            });
    }

    public getTemplateThumbnail(template: BuilderTemplate) {
        return this.settings.getBaseUrl(true) + '/' + template.thumbnail;
    }

    public filterByCategory(name: string|null) {
        this.selectedCategory = name;

        if ( ! name) return this.filteredTemplates = this.templatePagination.data.slice();

        this.filteredTemplates = this.templatePagination.data.filter(template => {
            return template.config.category.toLowerCase().indexOf(name.toLowerCase()) > -1;
        });
    }

    public filterByColor(name: string|null) {
        this.selectedColor = name;

        if ( ! name) return this.filteredTemplates = this.templatePagination.data.slice();

        this.filteredTemplates = this.templatePagination.data.filter(template => {
            return template.config.color.toLowerCase().indexOf(name.toLowerCase()) > -1;
        });
    }

    public addMoreTemplates(templatePagination: PaginationResponse<BuilderTemplate>) {
        const oldTemplates = this.templatePagination.data.slice();
        this.templatePagination = templatePagination;
        this.templatePagination.data.push(...oldTemplates);
        this.filteredTemplates = this.templatePagination.data;
        this.selectedCategory = null;
        this.selectedColor = null;
    }
}
